@@ -1,47 +1,37 @@
 #!/usr/local/bin/python
 '''
-:py:mod:`obicount` : Count the number of sequences 
-==================================================
+:py:mod:`obicount`: counts the number of sequence records 
+=========================================================
 
 .. codeauthor:: Eric Coissac <eric.coissac@metabarcoding.org>
 
-:py:mod:`obicount` count the number of sequences in a sequence file and/or their total count (use the 'count' annotation tag).
+:py:mod:`obicount` counts the number of sequence records and/or the sum of the ``count`` attributes.
 
-Example: To get the number of sequences in a file :
+*Example:*
 
-.. code-block:: bash
+    .. code-block:: bash
+        
+        > obicount seq.fasta  
 
-   > obicount seq.fasta 
-
-
-Example: To get the total count of the sequences in a file:
-
-.. code-block:: bash
-
-   > obicount -a seq.fasta
-   
-Example: To get both the number and the total count of the sequences in a file :
-
-.. code-block:: bash
-
-   > obicount -s seq.fasta
-    
+    Prints the number of sequence records contained in the ``seq.fasta`` 
+    file and the sum of their ``count`` attributes.
 '''
 
 from obitools.options import getOptionManager
 from obitools.format.options import addInOutputOption
 
 def addCountOptions(optionManager):
-    optionManager.add_option('-s','--sequence',
+    group=optionManager.add_option_group('Obicount specific options')
+    group.add_option('-s','--sequence',
                              action="store_true", dest="sequence",
                              default=False,
-                             help="Print the number sequences and their total count"
+                             help="Prints only the number of sequence records."
                              )
  
-    optionManager.add_option('-a','--all',
+    group.add_option('-a','--all',
                              action="store_true", dest="all",
                              default=False,
-                             help="Print the total count of the sequences (if a sequence has no 'count' tag its default count is 1)"
+                             help="Prints only the total count of sequence records (if a sequence has no `count` attribute, its default count is 1) (default: False)."
                              )
 
 
